diff -ur t3lib/class.t3lib_befunc.php t3lib/class.t3lib_befunc.php --- t3lib/class.t3lib_befunc.php 2011-01-25 17:05:01.000000000 +0100 +++ t3lib/class.t3lib_befunc.php 2011-01-25 18:23:47.000000000 +0100 @@ -3332,7 +3332,7 @@ * @return string a URL GET variable including ampersand */ public static function getUrlToken($formName = 'securityToken', $tokenName = 'formToken') { - $formprotection = t3lib_formprotection_Factory::get(); + $formprotection = t3lib_formprotection::get(); return '&' . $tokenName . '=' . $formprotection->generateToken($formName); } diff -ur t3lib/class.t3lib_pagerenderer.php t3lib/class.t3lib_pagerenderer.php --- t3lib/class.t3lib_pagerenderer.php 2011-01-25 17:05:01.000000000 +0100 +++ t3lib/class.t3lib_pagerenderer.php 2011-01-25 18:23:49.000000000 +0100 @@ -947,7 +947,7 @@ public function addExtDirectCode() { $token = ''; if (TYPO3_MODE === 'BE') { - $formprotection = t3lib_formprotection_Factory::get(); + $formprotection = t3lib_formprotection::get(); $token = $formprotection->generateToken('extDirect'); } diff -ur t3lib/class.t3lib_tceforms.php t3lib/class.t3lib_tceforms.php --- t3lib/class.t3lib_tceforms.php 2011-01-25 17:05:01.000000000 +0100 +++ t3lib/class.t3lib_tceforms.php 2011-01-25 18:23:48.000000000 +0100 @@ -4982,7 +4982,7 @@ * @return string a complete input field */ public static function getHiddenTokenField($formName = 'securityToken', $tokenName = 'formToken') { - $formprotection = t3lib_formprotection_Factory::get(); + $formprotection = t3lib_formprotection::get(); return ''; } diff -ur t3lib/extjs/class.t3lib_extjs_extdirectrouter.php t3lib/extjs/class.t3lib_extjs_extdirectrouter.php --- t3lib/extjs/class.t3lib_extjs_extdirectrouter.php 2011-01-25 17:11:29.000000000 +0100 +++ t3lib/extjs/class.t3lib_extjs_extdirectrouter.php 2011-01-25 18:23:47.000000000 +0100 @@ -89,7 +89,7 @@ $token = array_pop($singleRequest->data); if ($firstCall) { $firstCall = FALSE; - $formprotection = t3lib_formprotection_Factory::get(); + $formprotection = t3lib_formprotection::get(); $validToken = $formprotection->validateToken($token, 'extDirect'); } diff -ur t3lib/formprotection/class.t3lib_formprotection_backendformprotection.php t3lib/formprotection/class.t3lib_formprotection_backendformprotection.php --- t3lib/formprotection/class.t3lib_formprotection_backendformprotection.php 2011-01-25 17:33:10.000000000 +0100 +++ t3lib/formprotection/class.t3lib_formprotection_backendformprotection.php 2011-01-25 18:23:48.000000000 +0100 @@ -35,8 +35,8 @@ * matter; you only need it to get the form token for verifying it. * *
- * $formToken = t3lib_formprotection_Factory::get(
- *	 t3lib_formprotection_Factory::TYPE_BACK_END
+ * $formToken = t3lib_formprotection::get(
+ *	 t3lib_formprotection::TYPE_BACK_END
  * )->generateToken(
  *	 'BE user setup', 'edit'
  * );
@@ -53,8 +53,8 @@
  * For editing a tt_content record, the call could look like this:
  *
  * 
- * $formToken = t3lib_formprotection_Factory::get(
- *	 t3lib_formprotection_Factory::TYPE_BACK_END
+ * $formToken = t3lib_formprotection::get(
+ *	 t3lib_formprotection::TYPE_BACK_END
  * )->getFormProtection()->generateToken(
  *	'tt_content', 'edit', $uid
  * );
@@ -64,8 +64,8 @@
  * generated tokens get saved, and also that removed tokens stay removed:
  *
  * 
- * t3lib_formprotection_Factory::get(
- *	 t3lib_formprotection_Factory::TYPE_BACK_END
+ * t3lib_formprotection::get(
+ *	 t3lib_formprotection::TYPE_BACK_END
  * )->persistTokens();
  * 
* @@ -78,8 +78,8 @@ * that the form token is valid like this: * *
- * if ($dataHasBeenSubmitted && t3lib_formprotection_Factory::get(
- *		 t3lib_formprotection_Factory::TYPE_BACK_END
+ * if ($dataHasBeenSubmitted && t3lib_formprotection::get(
+ *		 t3lib_formprotection::TYPE_BACK_END
  *	 )->validateToken(
  *		 (string) t3lib_div::_POST('formToken'),
  *		 'BE user setup', 'edit
diff -ur t3lib/formprotection/class.t3lib_formprotection_factory.php t3lib/formprotection/class.t3lib_formprotection_factory.php
--- t3lib/formprotection/class.t3lib_formprotection_factory.php	2011-01-25 17:32:25.000000000 +0100
+++ t3lib/formprotection/class.t3lib_formprotection_factory.php	2011-01-25 18:23:47.000000000 +0100
@@ -23,7 +23,7 @@
  ***************************************************************/
 
 /**
- * Class t3lib_formprotection_Factory.
+ * Class t3lib_formprotection.
  *
  * This class creates and manages instances of the various form protection
  * classes.
@@ -33,7 +33,7 @@
  * Usage for the back-end form protection:
  *
  * 
- * $formProtection = t3lib_formprotection_Factory::get(
+ * $formProtection = t3lib_formprotection::get(
  *	 't3lib_formProtection_BackEnd'
  * );
  * 
@@ -41,7 +41,7 @@ * Usage for the install tool form protection: * *
- * $formProtection = t3lib_formprotection_Factory::get(
+ * $formProtection = t3lib_formprotection::get(
  *	 'tx_install_formprotection'
  * );
  * $formProtection->injectInstallTool($this);
@@ -55,7 +55,7 @@
  * @author Oliver Klee 
  * @author Ernesto Baschny 
  */
-final class t3lib_formprotection_Factory {
+final class t3lib_formprotection {
 	/**
 	 * created instances of form protections using the type as array key
 	 *
diff -ur typo3/alt_doc.php typo3/alt_doc.php
--- typo3/alt_doc.php	2011-01-25 17:05:01.000000000 +0100
+++ typo3/alt_doc.php	2011-01-25 18:23:49.000000000 +0100
@@ -1491,7 +1491,7 @@
 // Preprocessing, storing data if submitted to
 $SOBE->preInit();
 
-$formprotection = t3lib_formprotection_Factory::get();
+$formprotection = t3lib_formprotection::get();
 
 if ($SOBE->doProcessData())	{		// Checks, if a save button has been clicked (or the doSave variable is sent)
 	if ($formprotection->validateToken(t3lib_div::_GP('formToken'), 'editRecord')) {
diff -ur typo3/classes/class.ajaxlogin.php typo3/classes/class.ajaxlogin.php
--- typo3/classes/class.ajaxlogin.php	2011-01-25 17:05:01.000000000 +0100
+++ typo3/classes/class.ajaxlogin.php	2011-01-25 18:23:48.000000000 +0100
@@ -44,7 +44,7 @@
 	 */
 	public function login(array $parameters, TYPO3AJAX $ajaxObj) {
 		if ($GLOBALS['BE_USER']->user['uid']) {
-			$formprotection = t3lib_formprotection_Factory::get();
+			$formprotection = t3lib_formprotection::get();
 			$token = $formprotection->generateToken('extDirect');
 
 			$json = array(
diff -ur typo3/classes/class.clearcachemenu.php typo3/classes/class.clearcachemenu.php
--- typo3/classes/class.clearcachemenu.php	2011-01-25 17:05:01.000000000 +0100
+++ typo3/classes/class.clearcachemenu.php	2011-01-25 18:23:48.000000000 +0100
@@ -115,7 +115,7 @@
 			}
 		}
 
-		t3lib_formprotection_Factory::get()->persistTokens();
+		t3lib_formprotection::get()->persistTokens();
 	}
 
 	/**
diff -ur typo3/index.php typo3/index.php
--- typo3/index.php	2011-01-25 17:05:01.000000000 +0100
+++ typo3/index.php	2011-01-25 18:23:48.000000000 +0100
@@ -397,7 +397,7 @@
 			if (!$this->loginRefresh)	{
 				t3lib_utility_Http::redirect($this->redirectToURL);
 			} else {
-				$formprotection = t3lib_formprotection_Factory::get();
+				$formprotection = t3lib_formprotection::get();
 				$token = $formprotection->generateToken('extDirect');
 				$TBE_TEMPLATE->JScode.=$TBE_TEMPLATE->wrapScriptTags('
 					if (parent.opener && (parent.opener.busy || parent.opener.TYPO3.loginRefresh)) {
diff -ur typo3/tce_db.php typo3/tce_db.php
--- typo3/tce_db.php	2011-01-25 17:05:01.000000000 +0100
+++ typo3/tce_db.php	2011-01-25 18:23:48.000000000 +0100
@@ -246,7 +246,7 @@
 // Include files?
 foreach($SOBE->include_once as $INC_FILE)	include_once($INC_FILE);
 
-$formprotection = t3lib_formprotection_Factory::get();
+$formprotection = t3lib_formprotection::get();
 
 if ($formprotection->validateToken(t3lib_div::_GP('formToken'), 'tceAction')) {
 	$SOBE->initClipboard();
diff -ur typo3/template.php typo3/template.php
--- typo3/template.php	2011-01-25 17:05:10.000000000 +0100
+++ typo3/template.php	2011-01-25 18:23:48.000000000 +0100
@@ -926,7 +926,7 @@
 
 
 ':'') . $this->endOfPageJsBlock ;
-			t3lib_formprotection_Factory::get()->persistTokens();
+			t3lib_formprotection::get()->persistTokens();
 		}
diff -ur tests/t3lib/formprotection/t3lib_formprotection_FactoryTest.php tests/t3lib/formprotection/t3lib_formprotection_FactoryTest.php
--- tests/t3lib/formprotection/t3lib_formprotection_FactoryTest.php	2011-01-25 12:28:32.000000000 +0100
+++ tests/t3lib/formprotection/t3lib_formprotection_FactoryTest.php	2011-01-25 18:23:47.000000000 +0100
@@ -25,7 +25,7 @@
 require_once('fixtures/class.t3lib_formprotection_testing.php');
 
 /**
  * Testcase for the t3lib_formprotection_Factory class.
  *
  * $Id$
  *
@@ -35,12 +35,12 @@
  * @author Oliver Klee 
  * @author Ernesto Baschny 
  */
-class t3lib_formprotection_FactoryTest extends tx_phpunit_testcase {
+class t3lib_formprotectionTest extends tx_phpunit_testcase {
 	public function setUp() {
 	}
 
 	public function tearDown() {
-		t3lib_formprotection_Factory::purgeInstances();
+		t3lib_formprotection::purgeInstances();
 	}
 
 
@@ -54,7 +54,7 @@
 	 * @expectedException InvalidArgumentException
 	 */
 	public function getForInexistentClassThrowsException() {
-		t3lib_formprotection_Factory::get('noSuchClass');
+		t3lib_formprotection::get('noSuchClass');
 	}
 
 	/**
@@ -63,7 +63,7 @@
 	 * @expectedException InvalidArgumentException
 	 */
 	public function getForClassThatIsNoFormProtectionSubclassThrowsException() {
-		t3lib_formprotection_Factory::get('t3lib_formprotection_FactoryTest');
+		t3lib_formprotection::get('t3lib_formprotectionTest');
 	}
 
 	/**
@@ -71,7 +71,7 @@
 	 */
 	public function getForTypeBackEndWithExistingBackEndReturnsBackEndFormProtection() {
 		$this->assertTrue(
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_BackendFormProtection'
 			) instanceof t3lib_formprotection_BackendFormProtection
 		);
@@ -82,10 +82,10 @@
 	 */
 	public function getForTypeBackEndCalledTwoTimesReturnsTheSameInstance() {
 		$this->assertSame(
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_BackendFormProtection'
 			),
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_BackendFormProtection'
 			)
 		);
@@ -96,7 +96,7 @@
 	 */
 	public function getForTypeInstallToolReturnsInstallToolFormProtection() {
 		$this->assertTrue(
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_InstallToolFormProtection'
 			) instanceof t3lib_formprotection_InstallToolFormProtection
 		);
@@ -107,10 +107,10 @@
 	 */
 	public function getForTypeInstallToolCalledTwoTimesReturnsTheSameInstance() {
 		$this->assertSame(
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_InstallToolFormProtection'
 			),
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_InstallToolFormProtection'
 			)
 		);
@@ -121,10 +121,10 @@
 	 */
 	public function getForTypesInstallToolAndBackEndReturnsDifferentInstances() {
 		$this->assertNotSame(
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_InstallToolFormProtection'
 			),
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_BackendFormProtection'
 			)
 		);
@@ -140,13 +140,13 @@
 	 */
 	public function setSetsInstanceForType() {
 		$instance = new t3lib_formProtection_Testing();
-		t3lib_formprotection_Factory::set(
+		t3lib_formprotection::set(
 			't3lib_formprotection_BackendFormProtection', $instance
 		);
 
 		$this->assertSame(
 			$instance,
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_BackendFormProtection'
 			)
 		);
@@ -157,13 +157,13 @@
 	 */
 	public function setNotSetsInstanceForOtherType() {
 		$instance = new t3lib_formProtection_Testing();
-		t3lib_formprotection_Factory::set(
+		t3lib_formprotection::set(
 			't3lib_formprotection_BackendFormProtection', $instance
 		);
 
 		$this->assertNotSame(
 			$instance,
-			t3lib_formprotection_Factory::get(
+			t3lib_formprotection::get(
 				't3lib_formprotection_InstallToolFormProtection'
 			)
 		);
@@ -25,7 +25,7 @@
 
 /**
- * Testcase for the t3lib_formprotection_Factory class.
+ * Testcase for the t3lib_formprotection class.
  *
  * $Id$